@@ -18,7 +18,7 @@
 #
 #------------------------------------------------------------------------
 #
-#   $Id: Base.pm,v 2.63 2003/07/24 16:16:27 abw Exp $
+#   $Id: Base.pm,v 2.68 2004/01/12 12:37:49 abw Exp $
 #
 #========================================================================
  
@@ -30,7 +30,7 @@ use strict;
 use vars qw( $VERSION );
 use Template::Constants;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.63 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.68 $ =~ /(\d+)\.(\d+)/);
 
 
 #------------------------------------------------------------------------
@@ -138,6 +138,20 @@ sub debug {
 }
 
 
+#------------------------------------------------------------------------
+# module_version()
+#
+# Returns the current version number.
+#------------------------------------------------------------------------
+
+sub module_version {
+    my $self = shift;
+    my $class = ref $self || $self;
+    no strict 'refs';
+    return ${"${class}::VERSION"};
+}
+
+
 1;
 
 __END__
@@ -274,8 +288,8 @@ L<http://www.andywardley.com/|http://www.andywardley.com/>
 
 =head1 VERSION
 
-2.63, distributed as part of the
-Template Toolkit version 2.11, released on 06 January 2004.
+2.67, distributed as part of the
+Template Toolkit version 2.12, released on 12 January 2004.
 
 =head1 COPYRIGHT
 
@@ -287,4 +301,14 @@ modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template|Template>
\ No newline at end of file
+L<Template|Template>
+
+=cut
+
+# Local Variables:
+# mode: perl
+# perl-indent-level: 4
+# indent-tabs-mode: nil
+# End:
+#
+# vim: expandtab shiftwidth=4:
