@@ -25,7 +25,7 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Directive.pm,v 2.16 2002/07/19 13:29:38 abw Exp $
+# $Id: Directive.pm,v 2.18 2003/10/08 09:34:41 abw Exp $
 #
 #============================================================================
 
@@ -39,13 +39,13 @@ use Template::Constants;
 use Template::Exception;
 
 use base qw( Template::Base );
-use vars qw( $VERSION $DEBUG $PRETTY $WHILE_MAX );
+use vars qw( $VERSION $DEBUG $PRETTY $WHILE_MAX $OUTPUT );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.16 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.18 $ =~ /(\d+)\.(\d+)/);
 
 $WHILE_MAX = 1000 unless defined $WHILE_MAX;
 $PRETTY    = 0 unless defined $PRETTY;
-my $OUTPUT = '$output .= ';
+$OUTPUT    = '$output .= ';
 
 
 sub _init {
@@ -994,8 +994,7 @@ sub debug {
     my $hash = shift @$args;
     $args  = join(', ', @$file, @$args);
     $args .= @$hash ? ', { ' . join(', ', @$hash) . ' }' : '';
-#    print STDERR "factory debug($args)\n";
-    return "$OUTPUT \$context->debug($args); ## DEBUG ##"; 
+    return "$OUTPUT \$context->debugging($args); ## DEBUG ##"; 
 }
 
 
